==> frictionless-4.40.5-py2.py3-none-any.whl: frictionless/errors/table.py <==
from ..error import Error


class TableError(Error):
    code = "table-error"
    name = "Table Error"
    tags = ["#table"]
    template = "General table error: {note}"
    description = "There is a table error."


class FieldCountError(TableError):
    code = "field-count-error"
    name = "Field Count Error"
    template = "The data source does not match the expected field count: {note}"
    description = "This error can happen if the data is corrupted."


class RowCountError(TableError):
    code = "row-count-error"
    name = "Row Count Error"
    template = "The data source does not match the expected row count: {note}"
    description = "This error can happen if the data is corrupted."


class TableDimensionsError(TableError):
    code = "table-dimensions-error"
    name = "Table dimensions error"
    template = "The data source does not have the required dimensions: {note}"
    description = "This error can happen if the data is corrupted."

    def __init__(self, note, limits):
        self.setinitial("limits", limits)
        super().__init__(note=note)


class DeviatedValueError(TableError):
    code = "deviated-value"
    name = "Deviated Value"
    template = "There is a possible error because the value is deviated: {note}"
    description = "The value is deviated."


class DeviatedCellError(TableError):
    code = "deviated-cell"
    name = "Deviated cell"
    template = "There is a possible error because the cell is deviated: {note}"
    description = "The cell is deviated."

==> frictionless-5.0.0b21-py2.py3-none-any.whl: frictionless/errors/table.py <==
from __future__ import annotations
from .data import DataError


class TableError(DataError):
    type = "table-error"
    title = "Table Error"
    description = "There is a table error."
    template = "General table error: {note}"
    tags = ["#table"]


class FieldCountError(TableError):
    type = "field-count"
    title = "Field Count Error"
    description = "This error can happen if the data is corrupted."
    template = "The data source does not match the expected field count: {note}"


class RowCountError(TableError):
    type = "row-count"
    title = "Row Count Error"
    description = "This error can happen if the data is corrupted."
    template = "The data source does not match the expected row count: {note}"


class TableDimensionsError(TableError):
    type = "table-dimensions"
    title = "Table dimensions error"
    description = "This error can happen if the data is corrupted."
    template = "The data source does not have the required dimensions: {note}"


class DeviatedValueError(TableError):
    type = "deviated-value"
    title = "Deviated Value"
    description = "The value is deviated."
    template = "There is a possible error because the value is deviated: {note}"


class DeviatedCellError(TableError):
    type = "deviated-cell"
    title = "Deviated cell"
    description = "The cell is deviated."
    template = "There is a possible error because the cell is deviated: {note}"


class RequiredValueError(TableError):
    type = "required-value"
    title = "Required Value"
    description = "The required values are missing."
    template = "Required values not found: {note}"
